==> qt-creator-opensource-src-4.0.1.zip: qt-creator-opensource-src-4.0.1/src/plugins/ios/iossettingswidget.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef IOSSETTINGSWIDGET_H
#define IOSSETTINGSWIDGET_H

#include "iosconfigurations.h"

#include <QList>
#include <QString>
#include <QWidget>
#include <QAbstractTableModel>

QT_BEGIN_NAMESPACE
class Ui_IosSettingsWidget;
QT_END_NAMESPACE

namespace Ios {
namespace Internal {

class IosSettingsWidget : public QWidget
{
    Q_OBJECT
public:
    // Todo: This would be so much simpler if it just used Utils::PathChooser!!!
    IosSettingsWidget(QWidget *parent = 0);
    ~IosSettingsWidget();

    void saveSettings();

private slots:

private:
    void initGui();

    Ui_IosSettingsWidget *m_ui;
    bool m_saveSettingsRequested;
};

} // namespace Internal
} // namespace Ios

#endif // IOSSETTINGSWIDGET_H

==> qt-creator-opensource-src-4.2.1.zip: qt-creator-opensource-src-4.2.1/src/plugins/ios/iossettingswidget.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "iosconfigurations.h"

#include <QList>
#include <QString>
#include <QWidget>
#include <QAbstractTableModel>

QT_BEGIN_NAMESPACE
class Ui_IosSettingsWidget;
QT_END_NAMESPACE

namespace Ios {
namespace Internal {

class IosSettingsWidget : public QWidget
{
    Q_OBJECT
public:
    // Todo: This would be so much simpler if it just used Utils::PathChooser!!!
    IosSettingsWidget(QWidget *parent = 0);
    ~IosSettingsWidget();

    void saveSettings();

private:
    void initGui();

    Ui_IosSettingsWidget *m_ui;
    bool m_saveSettingsRequested;
};

} // namespace Internal
} // namespace Ios
